searchui/indevicehandler/inc/indevicehandler.h
changeset 17 7d8c8d8f5eab
parent 2 208a4ba3894c
--- a/searchui/indevicehandler/inc/indevicehandler.h	Tue Jul 06 14:17:22 2010 +0300
+++ b/searchui/indevicehandler/inc/indevicehandler.h	Wed Aug 18 09:49:49 2010 +0300
@@ -32,9 +32,8 @@
 #define DEFAULT_SEARCH_FIELD "_aggregate"
 #endif
 
-class QCPixSearcher;
-class QCPixDocument;
-
+class CpixSearcher;
+class CpixDocument;
 SEARCH_CLASS(SearchInDeviceHandlerTest)
 
 /**
@@ -76,12 +75,18 @@
      * Signalled when user requests for the result item
      * error and result item will be returned
      */
-    void handleDocument(int aError, QCPixDocument* aDoc);
+    void handleDocument(int aError, CpixDocument* aDoc);
+
+    /**
+     * Signalled when user requests for the result item in batch
+     * error and result item will be returned
+     */
+    void handleBatchDocument(int aError, int aCount, CpixDocument** aDoc);
 
 private slots:
 
     /**
      * slot connects to QCPixSearcher to get the status of search results 
      * @since S60 ?S60_version.
      * @param aError error code.
      * @param aEstimatedResultCount number of results
@@ -90,12 +95,22 @@
     void getSearchResult(int aError, int aEstimatedResultCount);
 
     /**
      * slot connects to QCPixSearcher to get the result item 
      * @since S60 ?S60_version.
      * @param aError error code.
      * @param aDocument result item
      */
-    void getDocumentAsync(int aError, QCPixDocument* aDocument);
+    void getDocumentAsync(int aError, CpixDocument* aDocument);
+
+    /**
+     * slot connects to CpixSearcher to get the result item 
+     * @since S60 ?S60_version.
+     * @param aError error code.
+     * @param aCount number of result item.
+     * @param aDocument array of Documents
+     */
+    void getBatchDocumentAsync(int aError, int aCount,
+            CpixDocument** aDocument);
 
 public:
 
@@ -104,7 +119,7 @@
      * @since S60 ?S60_version.
      * @param aIndex index 
      */
-    QCPixDocument* getDocumentAtIndex(int aIndex);
+    CpixDocument* getDocumentAtIndex(int aIndex);
 
     /**
      * returns the result item asynchronously.
@@ -113,7 +128,13 @@
      */
     void getDocumentAsyncAtIndex(int aIndex);
 
-  
+    /**
+     * returns the result item asynchronously.
+     * @since S60 ?S60_version.
+     * @param aIndex index 
+     * @param aCount number of result item
+     */
+    void getBatchDocumentAsyncAtIndex(int aIndex, int aCount);
 
     /**
      * initate the search asynchronously.
@@ -156,14 +177,14 @@
      * interface for CPix.
      * Own.
      */
-    QCPixSearcher *mSearchInterface;
+    CpixSearcher *mSearchInterface;
 
     /**
      * number of results on current search.        
      */
     int mSearchResultCount;
 
-SEARCH_FRIEND_CLASS    (SearchInDeviceHandlerTest)
+    SEARCH_FRIEND_CLASS (SearchInDeviceHandlerTest)
     };
 
 #endif //INDEVICEHANDLER_H
@@ -76,12 +75,18 @@
 
     /**
-     * slot connects to QCPixSearcher to get the status of search results 
+     * slot connects to CpixSearcher to get the status of search results 
      * @since S60 ?S60_version.
      * @param aError error code.
@@ -90,12 +95,22 @@
 
     /**
-     * slot connects to QCPixSearcher to get the result item 
+     * slot connects to CpixSearcher to get the result item 
      * @since S60 ?S60_version.
      * @param aError error code.